  /****************************************************************************
  * Title                 :   BIG 7 SEG R click
  * Filename              :   Big7SEGAVR.c
  * Author                :   SP
  * Origin Date           :   17/11/2016
  *****************************************************************************/
  /**
  * @note Test configuration:
  * MCU:             P32MX795F512L
  * Dev.Board:       EasyPIC Fusion v7
  * Oscillator:      72 MHz external
  * Ext. Modules:    BIG 7-SEG R Click
  * SW:              PIC32 v3.6.0
  * NOTES:
    - Place BIG 7-SEG R click board on mikroBUS slot 1
    - PWM: RD0
    - RESET: RC1
    - LATCH: RC2
  *
  /******************************************************************************
  * Includes
  *******************************************************************************/
   #include "7_Seg.h"
  /******************************************************************************
  * Preprocessor Constants
  *******************************************************************************/

  /******************************************************************************
  * Configuration Constants
  *******************************************************************************/

  /******************************************************************************
  * Macros
  *******************************************************************************/

  /******************************************************************************
  * Typedefs
  *******************************************************************************/

  /* Module Variable Definitions
  *******************************************************************************/
  sbit HC595_RES at RC1_bit;
  sbit HC595_LAT at RC2_bit;
  sbit HC595_PWM at RD0_bit;
  /******************************************************************************

  /******************************************************************************
  * Function Definitions
  *******************************************************************************/
  extern char dig_array[MAX_CHARACTERS];

  //variables
  unsigned short counter;
  unsigned int luminosity;
  unsigned int pwm_period;
  int8_t valid;

  char demo_array[20] =
  { 'M', 'I', 'K', 'R', 'O',
    'E', 'L', 'E', 'K', 'T', 'R', 'O', 'N', 'I', 'K', 'A',
    '2', '0', '1', '6'
  };

  void main()
    {
      // MCU Init
       JTAGEN_bit = 0;
       AD1PCFG = 0xFFFF;                          // Configure AN pins as digital I/O
       TRISC1_bit = 0;                            // Configure PORTC pin 1 as output
       TRISC2_bit = 0;                            // Configure PORTC pin 2 as output
       TRISD0_bit = 0;                            // Configure PORTD pin 0 as output

       // SPI Init
       SPI3_Init_Advanced(_SPI_MASTER, 
                          _SPI_16_BIT, 
                          1, 
                          _SPI_SS_DISABLE, 
                          _SPI_DATA_SAMPLE_MIDDLE, 
                          _SPI_CLK_IDLE_HIGH, 
                          _SPI_ACTIVE_2_IDLE);

       SPI_Set_Active(SPI3_Read, SPI3_Write);
       
       Delay_ms(100);
       pwm_period = PWM_Init(5000 , 1, 1, 2);     // PWM Initialization
       PWM_Start(1);
       PWM_Set_Duty(4000,  1);                    // Set current duty for PWM1

       // 74HC595 Init
       HC595_LAT = 0;
       HC595_RES = 0;
       HC595_reset();

       // Init counter and segment luminosity
       counter = 0;
       luminosity = 0;

       // Endless loop
       while ( 1 )
        {
           valid = seg_7_display(demo_array[counter]);
           PWM_Set_Duty(4000 - luminosity,  1);
           delay_ms(750);
           luminosity += 100;
           counter++;

           if (counter == 20)    
             counter = 0;      
           if (luminosity == 3000)    
             luminosity = 0;      
        }
  }